==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/da_DK.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG modul';
$lang['uninstalled'] = 'Modulet blev afinstalleret';
$lang['installed'] = 'Modul version %s blev installeret';
$lang['stripbackgroundtags'] = 'Fjern Baggrunds-Tags fra CSS';
$lang['source_formatting_text'] = 'Format&eacute;r HTML-koden';
$lang['dropdownblockformats_text'] = 'Blockformatering  i dropdown-menu';
$lang['allowtables'] = 'Tillad tabel funktioner';
$lang['newlinestyle_text'] = 'Ny linie-metode';
$lang['pstyle'] = '< p > metode';
$lang['brstyle'] = '< br/ > metode';
$lang['usecompressiontext'] = 'Benyt gz kompression';
$lang['usecompressionhelp'] = 'Dette kan g&oslash;re indl&aelig;sningen af TinyMCE hurtigere, men ogs&aring; forhindre korrekt indl&aelig;sning p&aring; nogle systemer. Benyt kun hvis du ved hvad du g&oslash;r.';
$lang['forcedrootblocktext'] = 'Tving < p >-grund-blok';
$lang['forcedrootblockhelp'] = 'Tvinger det returnerede indhold til i det mindste af v&aelig;re omkranset af en < p >-tag';
$lang['filepickerstyle'] = 'Filv&aelig;lger-stil';
$lang['filepickersize'] = 'Filv&aelig;lger st&oslash;rrelse';
$lang['allowuploadtext'] = 'Tillad upload og mappe-oprettelse i Filv&aelig;lger';
$lang['cannotreadconfig'] = 'Kan ikke l&aelig;se tinyconfig.php direkte, s&aring; TinyMCE vil formentlig ikke virke. Du skal kontrollere rettigheder p&aring; denne fil og mappen den ligger i, disse b&oslash;r tillade l&aelig;sning, men kun skrivning for ejeren.';
$lang['filenameonly'] = 'Vis filnavne';
$lang['thumbnailsonly'] = 'Vis billedeeksempler';
$lang['showthumbnailfilestext'] = 'Vis billedeksempler i listerne';
$lang['filenameandthumbnails'] = 'Vis b&aring;de filnavne og billedeksempler';
$lang['skinstext'] = 'Udseende';
$lang['skinvariationtext'] = 'Variation af udseende';
$lang['advancedwarning'] = '<strong>Advarsel!<br/>Ved at &aelig;ndre disse indstillinger risikerer du at  TinyMCE holde op med at virker eller at den resulterende kode ikke er korrekt. Lav kun &aelig;ndringer her hvsi du ved hvad du g&oslash;r. Og l&aelig;s venligst p&aring; TinyMCE&#039;s web site f&oslash;r du laver &aelig;ndringer.</strong>';
$lang['entityencoding_text'] = 'Kodning af specielle karakterer';
$lang['rawencoding'] = 'Raw kodning (hurtigtst, virker i de fleste tilf&aelig;lde)';
$lang['namedencoding'] = 'Navngiven kodning (som &amp; nbsp;)';
$lang['numericencoding'] = 'Numerisk kodning (som &amp;#160;)';
$lang['show_path_text'] = 'Vis stien til elementet i bunden af editoren';
$lang['toolbar_tab'] = 'V&aelig;rkt&oslash;jslinie';
$lang['toolbar_help'] = 'Disse valgmuligheder skulle indeholde en kommasepareret liste af button/control navne til at inds&aelig;tte i toolbaren. Du kan benytte | tegnet i stedet for ordet &#039;seperator&#039;';
$lang['toolbar_text'] = 'V&aelig;rkt&oslash;jslinie';
$lang['toolbarhelptext'] = 'Klik her for at se v&aelig;rkt&oslash;jslinie-vejledningen i TinyMCE-wiki&#039;en';
$lang['editor_width_text'] = 'Editor feltets bredde';
$lang['editor_height_text'] = 'Editor feltets h&oslash;jde';
$lang['auto'] = 'Automatisk';
$lang['or'] = 'eller';
$lang['datetimeformat_text'] = 'Dato/Tid format';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Dato';
$lang['datetimeformat_help'] = 'Klik her for at hvordan dato/tid formateres';
$lang['extraconfigtext'] = 'Ekstra konfiguration';
$lang['extraconfighelp'] = 'Se TinyMCE-wiki for instruktioner.';
$lang['customdropdowntext'] = 'Brugerdefineret menu';
$lang['customdropdownhelp'] = 'Giver mulighed for at brugerdefinerede stumper kode kan inds&aelig;ttes ved at v&aelig;lge i en menu. Man kunne forstille sig nem inds&aelig;ttelse af tags mm. Menuen placeres i v&aelig;rkt&oslash;jslinien ved at inds&aelig;tte &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Sl&aring;et til fra starten';
$lang['startenabledhelp'] = 'Hvis dette sl&aring;s fra startes Tiny-editorene som sl&aring;et fra. Dette b&oslash;r bruges sammen med knappen til at sl&aring; dem til og fra dynamisk.';
$lang['loadcmslinkertext'] = 'Indl&aelig;s CMSms-link&#039;eren';
$lang['loadcmslinkerhelp'] = 'Dette genererer den n&oslash;dvendige javascript-kode der skal til for at give mulighed for at tilf&oslash;je &#039;cmslinker&#039; til v&aelig;rkt&oslash;jslinien.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-stil';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stil';
$lang['ahrefstyle'] = '< a href >-stil';
$lang['relativeurlstext'] = 'Lav relative-stier';
$lang['forcecleanpastetext'] = 'Tving rensning ved inds&aelig;tning';
$lang['forcecleanpastehelp'] = 'Dette skal v&aelig;re sl&aring;et til for at indsat indhold renses for s&aelig;re kode fra f.eks. Word';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'Lad st&aring; tom eller s&aelig;t til default for at bruge PAGE CSS. Note: Baggrundsfarven s&aelig;ttes til hvid, ved at inds&aelig;tte f&oslash;lgende: background-color: white;';
$lang['includeonlyscreencss_text'] = 'Inklud&eacute;r kun sk&aelig;rm-CSS';
$lang['includeonlyscreencss_help'] = 'Hvis dette er sl&aring;et til inkluderes kun stylesheets forbundet med sk&aelig;rm-medietypen i de styles som TinyMCE h&aring;ndterer.';
$lang['usestaticconfigtext'] = 'Benyt statisk konfiguration';
$lang['usestaticconfighelp'] = 'Dette kan hj&aelig;lpe med at f&aring; Tiny til at virke p&aring; systemer hvor hosting&#039;en automatisk tilf&oslash;jer ting til filerne, hvilket kan &oslash;del&aelig;gge f.eks. dynamisk genererede javascript-filer.';
$lang['usestaticconfigwarning'] = 'Advarsel! Du har statisk konfiguration sl&aring;et til men der kan ikke skrives til /tmp/. Dette g&oslash;r det umuligt for modelet at gemme den statistk konfigurations-fil og vil h&oslash;jst sandsynligt g&oslash;re at TinyMCE ikke virker.';
$lang['showtogglebutton_text'] = 'Vis checkbox til at sl&aring; wysiwyg til/fra';
$lang['togglewysiwyg'] = 'Sl&aring; WYSIWYG til/fra';
$lang['styles_tab'] = 'CSS stilarter';
$lang['styles_help'] = 'Hvis du lader dette felt v&aelig;re tomt, vil TinyMCE indl&aelig;se din css-fil og vise stilarterne fra den p&aring; stil-listen. Hvis du kun &oslash;nsker enkelte stilarter vist, kan de skrives herunder i formatet &quot;MinStil1=stilart1; MinStil2=stilart2&quot;.';
$lang['css_styles_text'] = 'Generelt';
$lang['accessdenied'] = 'Adgang n&aelig;gtet. Check dine tilladelser.';
$lang['error'] = 'Fejl';
$lang['submit'] = 'Send';
$lang['update'] = 'Opdater';
$lang['settings'] = 'Indstillinger';
$lang['settingssaved'] = 'Indstillinger blev gemt';
$lang['advancedsaved'] = 'Avancerede indstillinger gemt';
$lang['toolbarsaved'] = 'V&aelig;rkt&oslash;jslinien blev gemt';
$lang['stylessaved'] = 'Styles blev gemt';
$lang['testareatext'] = 'Test omr&aring;de, intet indhold vil blive skadet ved at lege her....';
$lang['reset'] = 'Genskab standardindstillinger';
$lang['resetall'] = 'Genskab alle standardindstillinger';
$lang['confirmreset'] = 'Er du sikker p&aring; du vil genskabe disse standardindstillinger?';
$lang['confirmresetall'] = 'Er du sikker p&aring; du vil genskabe ALLE standardindstillinger?';
$lang['settingsreset'] = 'Standardindstillingerne blev genskabt';
$lang['allsettingsreset'] = 'Alle standardindstillinger blev genskabt';
$lang['upgraded'] = 'er blevet opgraderet til';
$lang['customdropdown'] = 'Brugerdefineret menu';
$lang['cmsmslinker'] = 'Inds&aelig;t link til cmsms-side';
$lang['backend_toolbars'] = 'Backend v&aelig;rkt&oslash;jslinie';
$lang['frontend_toolbars'] = 'Frontend v&aelig;rkt&oslash;jslinie';
$lang['plugins_tab'] = 'Udvidelser';
$lang['plugins_help'] = 'V&aelig;lg de udvidelser du &oslash;nsker at aktivere. Dokumentation kan findes  <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">her</a>';
$lang['plugins_text'] = 'Udvidelser';
$lang['saveplugins'] = 'Gem udvidelser';
$lang['pluginssaved'] = 'Udvidelser gemt';
$lang['youareintext'] = 'Du er i';
$lang['loadstylesheettext'] = 'Indl&aelig;s stylesheet for indholdet (anbefalet)';
$lang['extrastylestext'] = 'Tilf&oslash;jelser til stylesheet';
$lang['extrastyleshelp'] = 'CSS der skrives her tilf&oslash;jes til det stylesheet TinyMCE l&aelig;ser, efter de styles som den f&aring;r fra CMSms.';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'Ny mappe';
$lang['createdir'] = 'Opret';
$lang['nodirname'] = 'Intet mappenavn givet';
$lang['direxists'] = 'Mappen eksisterer allerede';
$lang['newdircreated'] = 'Mappen blev oprettet';
$lang['newdirfailed'] = 'Der skete en fejl ved oprettelse af mappen';
$lang['nofile'] = 'Ingen fil blev upload&#039;et';
$lang['filetoobig'] = 'Den upload&#039;ede fil er for stor';
$lang['uploadfailed'] = 'Der skete en fejl ved flytning af den upload&#039;ede fil';
$lang['fileuploaded'] = 'Filen blev upload&#039;et';
$lang['filepickertitle'] = 'CMS MadeSimple Fil V&aelig;lger';
$lang['success'] = 'Succes';
$lang['fileoperations'] = 'Fil operationer';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Str.';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avanceret';
$lang['help'] = '	<h3>Hvad g&oslash;r dette modul?</h3>
	<p>Tillader at TinyMCE kan bruges som WYSIWYG-editor.</p>
	<h3>Hvordan bruger jeg det??</h3>
	<p>Install&eacute;r det, g&aring; til bruger indstillinger og v&aelig;lg TinyMCE som det &oslash;nskede WYSIWYG-system.</p>

<h3>Probleml&oslash;sning</h3>
	Nogle brugere har problemer med at Tiny ikke viser sig efter installation eller opgradering. Her er en liste af ting der kan pr&oslash;ves f&oslash;r udviklerne kontaktes.
	<br/>
	<ul>
	<li>1. Pr&oslash;v venligst at upload&#039;e modules/TinyMCE-mappen til din server igen. I forbavsende mange tilf&aelig;lde har problemet v&aelig;ret manglende filer pga. fejl i upload.</li>
	<li>2. Pr&oslash;v at sl&aring; Statisk konfiguration til. Bem&aelig;rk at dette kr&aelig;ver at du har skriverettigheder til /tmp/-mappen p&aring; serveren</li>
	<li>3. Hvis du lige har opgraderet, s&aring; nulstil alle indstillinger. Dette er ikke rart, hvis du har konfigureret en masse, det ved jeg, men der er sket en v&aelig;ldig masse &aelig;ndringer fra 2.3.x til 2.4.x versionerne af modulet.
<li>4. Pr&oslash;v at sl&aring; funktionen statisk konfiguration til. Dette virker bedre p&aring; nogle systemer (CGI-PHP f.eks.)
	</ul>
	<br/>
		
';
$lang['utma'] = '156861353.2155648126422823700.1234651492.1235432734.1235521495.4';
$lang['utmz'] = '156861353.1234651492.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/TinyMCE/lang/ext/da_DK.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG modul';
$lang['uninstalled'] = 'Modulet blev afinstalleret';
$lang['installed'] = 'Modul version %s blev installeret';
$lang['stripbackgroundtags'] = 'Fjern Baggrunds-Tags fra CSS';
$lang['stiptags_help'] = 'Dette fors&oslash;ger at fjerne baggrundsindstillinger fra stylesheet&#039;et.';
$lang['source_formatting_text'] = 'Format&eacute;r HTML-koden';
$lang['dropdownblockformats_text'] = 'Blockformatering  i dropdown-menu';
$lang['allowtables'] = 'Tillad tabel funktioner';
$lang['newlinestyle_text'] = 'Ny linie-metode';
$lang['pstyle'] = '< p > metode';
$lang['brstyle'] = '< br/ > metode';
$lang['usecompressiontext'] = 'Benyt gz kompression';
$lang['usecompressionhelp'] = 'Dette kan g&oslash;re indl&aelig;sningen af TinyMCE hurtigere, men ogs&aring; forhindre korrekt indl&aelig;sning p&aring; nogle systemer. Benyt kun hvis du ved hvad du g&oslash;r.';
$lang['forcedrootblocktext'] = 'Tving < p >-grund-blok';
$lang['forcedrootblockhelp'] = 'Tvinger det returnerede indhold til i det mindste af v&aelig;re omkranset af en < p >-tag';
$lang['filepickerstyle'] = 'Filv&aelig;lger-stil';
$lang['filepickersize'] = 'Filv&aelig;lger st&oslash;rrelse';
$lang['allowuploadtext'] = 'Tillad upload og mappe-oprettelse i Filv&aelig;lger';
$lang['allowscalingtext'] = 'Tillad on-the-fly skalering af upload&#039;ede billeder';
$lang['scalingdimensionstext'] = 'Standard dimensioner';
$lang['resizeto'] = 'Skal&eacute;r til:';
$lang['useadvancedprofile'] = 'Tillad avanceret TinyMCE-profil';
$lang['saveprofile'] = 'Gem profil';
$lang['profilesaved'] = 'Profilen blev gemt';
$lang['profiles_tab'] = 'Profiler';
$lang['advanced_backend_toolbars'] = 'Avanceret backend profil indstillinger';
$lang['savestyles'] = 'Gem stilarter';
$lang['allowadvancedprofile'] = 'Tillad brug af den avancerede profil i TinyMCE';
$lang['showfilemanagement'] = 'Vis filh&aring;ndterings muligheder';
$lang['showfilemanagementhelp'] = 'Viser filh&aring;ndtering muligheder s&aring;som upload, mkdir og sletning af filer i FilV&aelig;lgeren';
$lang['deleteconfirmation'] = 'Er du sikker p&aring; denne fil skal slettes?';
$lang['deletefilesuccess'] = 'blev slettet';
$lang['deletefilefila'] = 'kunne ikke slettes';
$lang['cannotreadconfig'] = 'Kan ikke l&aelig;se tinyconfig.php direkte, s&aring; TinyMCE vil formentlig ikke virke. Du skal kontrollere rettigheder p&aring; denne fil og mappen den ligger i, disse b&oslash;r tillade l&aelig;sning, men kun skrivning for ejeren.';
$lang['filenameonly'] = 'Vis filnavne';
$lang['thumbnailsonly'] = 'Vis billedeeksempler';
$lang['showthumbnailfilestext'] = 'Vis billedeksempler i listerne';
$lang['filenameandthumbnails'] = 'Vis b&aring;de filnavne og billedeksempler';
$lang['skinstext'] = 'Udseende';
$lang['skinvariationtext'] = 'Variation af udseende';
$lang['advancedwarning'] = '<strong>Advarsel!<br/>Ved at &aelig;ndre disse indstillinger risikerer du at  TinyMCE holde op med at virker eller at den resulterende kode ikke er korrekt. Lav kun &aelig;ndringer her hvsi du ved hvad du g&oslash;r. Og l&aelig;s venligst p&aring; TinyMCE&#039;s web site f&oslash;r du laver &aelig;ndringer.</strong>';
$lang['entityencoding_text'] = 'Kodning af specielle karakterer';
$lang['rawencoding'] = 'Raw kodning (hurtigtst, virker i de fleste tilf&aelig;lde)';
$lang['namedencoding'] = 'Navngiven kodning (som &amp; nbsp;)';
$lang['numericencoding'] = 'Numerisk kodning (som &amp;#160;)';
$lang['show_path_text'] = 'Vis stien til elementet i bunden af editoren';
$lang['toolbar_tab'] = 'V&aelig;rkt&oslash;jslinie';
$lang['toolbar_help'] = 'Disse valgmuligheder skulle indeholde en kommasepareret liste af button/control navne til at inds&aelig;tte i toolbaren. Du kan benytte | tegnet i stedet for ordet &#039;seperator&#039;';
$lang['toolbar_text'] = 'V&aelig;rkt&oslash;jslinie';
$lang['toolbarhelptext'] = 'Klik her for at se v&aelig;rkt&oslash;jslinie-vejledningen i TinyMCE-wiki&#039;en';
$lang['editor_width_text'] = 'Editor feltets bredde';
$lang['editor_height_text'] = 'Editor feltets h&oslash;jde';
$lang['auto'] = 'Automatisk';
$lang['or'] = 'eller';
$lang['datetimeformat_text'] = 'Dato/Tid format';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Dato';
$lang['datetimeformat_help'] = 'Klik her for at hvordan dato/tid formateres';
$lang['extraconfigtext'] = 'Ekstra konfiguration';
$lang['extraconfighelp'] = 'En kommando pr. linie, ingen kommaer, tak. Se TinyMCE-wiki for instruktioner.';
$lang['customdropdowntext'] = 'Brugerdefineret menu';
$lang['customdropdownhelp'] = 'Giver mulighed for at brugerdefinerede stumper kode kan inds&aelig;ttes ved at v&aelig;lge i en menu. Man kunne forstille sig nem inds&aelig;ttelse af tags mm. Menuen placeres i v&aelig;rkt&oslash;jslinien ved at inds&aelig;tte &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Sl&aring;et til fra starten';
$lang['startenabledhelp'] = 'Hvis dette sl&aring;s fra startes Tiny-editorene som sl&aring;et fra. Dette b&oslash;r bruges sammen med knappen til at sl&aring; dem til og fra dynamisk.';
$lang['loadcmslinkertext'] = 'Indl&aelig;s CMSms-link&#039;eren';
$lang['loadcmslinkerhelp'] = 'Dette genererer den n&oslash;dvendige javascript-kode der skal til for at give mulighed for at tilf&oslash;je &#039;cmslinker&#039; til v&aelig;rkt&oslash;jslinien.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-stil';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stil';
$lang['ahrefstyle'] = '< a href >-stil';
$lang['relativeurlstext'] = 'Lav relative-stier';
$lang['forcecleanpastetext'] = 'Tving rensning ved inds&aelig;tning';
$lang['forcecleanpastehelp'] = 'Dette skal v&aelig;re sl&aring;et til for at indsat indhold renses for s&aelig;re kode fra f.eks. Word';
$lang['bodycss_text'] = 'Body tag CSS';
$lang['bodycss_help'] = 'Lad st&aring; tom eller s&aelig;t til default for at bruge PAGE CSS. Note: Baggrundsfarven s&aelig;ttes til hvid, ved at inds&aelig;tte f&oslash;lgende: background-color: white;';
$lang['includeonlyscreencss_text'] = 'Inklud&eacute;r kun sk&aelig;rm-CSS';
$lang['includeonlyscreencss_help'] = 'Hvis dette er sl&aring;et til inkluderes kun stylesheets forbundet med sk&aelig;rm-medietypen i de styles som TinyMCE h&aring;ndterer.';
$lang['usestaticconfigtext'] = 'Benyt statisk konfiguration';
$lang['usestaticconfighelp'] = 'Dette kan hj&aelig;lpe med at f&aring; Tiny til at virke p&aring; systemer hvor hosting&#039;en automatisk tilf&oslash;jer ting til filerne, hvilket kan &oslash;del&aelig;gge f.eks. dynamisk genererede javascript-filer.';
$lang['usestaticconfigwarning'] = 'Advarsel! Du har statisk konfiguration sl&aring;et til men der kan ikke skrives til /tmp/. Dette g&oslash;r det umuligt for modelet at gemme den statistk konfigurations-fil og vil h&oslash;jst sandsynligt g&oslash;re at TinyMCE ikke virker.';
$lang['showtogglebutton_text'] = 'Vis checkbox til at sl&aring; wysiwyg til/fra';
$lang['togglewysiwyg'] = 'Sl&aring; WYSIWYG til/fra';
$lang['styles_tab'] = 'CSS stilarter';
$lang['styles_help'] = 'Hvis du lader dette felt v&aelig;re tomt, vil TinyMCE indl&aelig;se din css-fil og vise stilarterne fra den p&aring; stil-listen. Hvis du kun &oslash;nsker enkelte stilarter vist, kan de skrives herunder i formatet &quot;MinStil1=stilart1; MinStil2=stilart2&quot;.';
$lang['css_styles_text'] = 'Generelt';
$lang['accessdenied'] = 'Adgang n&aelig;gtet. Check dine tilladelser.';
$lang['error'] = 'Fejl';
$lang['submit'] = 'Send';
$lang['update'] = 'Opdater';
$lang['savesettings'] = 'Gem indstillinger';
$lang['settings'] = 'Indstillinger';
$lang['settingssaved'] = 'Indstillinger blev gemt';
$lang['saveadvanced'] = 'Gem avancerede indstillinger';
$lang['advancedsaved'] = 'Avancerede indstillinger gemt';
$lang['toolbarsaved'] = 'V&aelig;rkt&oslash;jslinien blev gemt';
$lang['stylessaved'] = 'Styles blev gemt';
$lang['testareatext'] = '<p>Test omr&aring;de, intet indhold vil blive skadet ved at lege her....</p>';
$lang['reset'] = 'Genskab standardindstillinger';
$lang['resetall'] = 'Genskab alle standardindstillinger';
$lang['confirmreset'] = 'Er du sikker p&aring; du vil genskabe disse standardindstillinger?';
$lang['confirmresetall'] = 'Er du sikker p&aring; du vil genskabe ALLE standardindstillinger?';
$lang['settingsreset'] = 'Standardindstillingerne blev genskabt';
$lang['allsettingsreset'] = 'Alle standardindstillinger blev genskabt';
$lang['upgraded'] = 'er blevet opgraderet til';
$lang['customdropdown'] = 'Brugerdefineret menu';
$lang['cmsmslinker'] = 'Inds&aelig;t link til cmsms-side';
$lang['backend_toolbars'] = 'Backend profil indstillinger';
$lang['frontend_toolbars'] = 'Frontend profil indstillinger';
$lang['plugins_tab'] = 'Udvidelser';
$lang['plugins_help'] = 'V&aelig;lg de udvidelser du &oslash;nsker at aktivere. Dokumentation kan findes  <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">her</a>';
$lang['plugins_text'] = 'Udvidelser';
$lang['saveplugins'] = 'Gem udvidelser';
$lang['pluginssaved'] = 'Udvidelser gemt';
$lang['youareintext'] = 'Du er i';
$lang['loadstylesheettext'] = 'Indl&aelig;s stylesheet for indholdet (anbefalet)';
$lang['extrastylestext'] = 'Tilf&oslash;jelser til stylesheet';
$lang['extrastyleshelp'] = 'CSS der skrives her tilf&oslash;jes til det stylesheet TinyMCE l&aelig;ser, efter de styles som den f&aring;r fra CMSms.';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Upload';
$lang['createnewdir'] = 'Ny mappe';
$lang['createdir'] = 'Opret';
$lang['nodirname'] = 'Intet mappenavn givet';
$lang['direxists'] = 'Mappen eksisterer allerede';
$lang['newdircreated'] = 'Mappen blev oprettet';
$lang['newdirfailed'] = 'Der skete en fejl ved oprettelse af mappen';
$lang['nofile'] = 'Ingen fil blev upload&#039;et';
$lang['filetoobig'] = 'Den upload&#039;ede fil er for stor';
$lang['uploadfailed'] = 'Der skete en fejl ved flytning af den upload&#039;ede fil';
$lang['fileuploaded'] = 'Filen blev upload&#039;et';
$lang['filepickertitle'] = 'CMS MadeSimple Fil V&aelig;lger';
$lang['success'] = 'Succes';
$lang['fileoperations'] = 'Fil operationer';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Str.';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avanceret';
$lang['help'] = '	<h3>Hvad g&oslash;r dette modul?</h3>
	<p>Tillader at TinyMCE kan bruges som WYSIWYG-editor.</p>
	<h3>Hvordan bruger jeg det??</h3>
	<p>Install&eacute;r det, g&aring; til bruger indstillinger og v&aelig;lg TinyMCE som det &oslash;nskede WYSIWYG-system.</p>

<h3>Probleml&oslash;sning</h3>
	Nogle brugere har problemer med at Tiny ikke viser sig efter installation eller opgradering. Her er en liste af ting der kan pr&oslash;ves f&oslash;r udviklerne kontaktes.
	<br/>
	<ul>
	<li>1. Pr&oslash;v venligst at upload&#039;e modules/TinyMCE-mappen til din server igen. I forbavsende mange tilf&aelig;lde har problemet v&aelig;ret manglende filer pga. fejl i upload.</li>
	<li>2. Pr&oslash;v at sl&aring; Statisk konfiguration til. Bem&aelig;rk at dette kr&aelig;ver at du har skriverettigheder til /tmp/-mappen p&aring; serveren</li>
	<li>3. Hvis du lige har opgraderet, s&aring; nulstil alle indstillinger. Dette er ikke rart, hvis du har konfigureret en masse, det ved jeg, men der er sket en v&aelig;ldig masse &aelig;ndringer fra 2.3.x til 2.4.x versionerne af modulet.
<li>4. Pr&oslash;v at sl&aring; funktionen statisk konfiguration til. Dette virker bedre p&aring; nogle systemer (CGI-PHP f.eks.)
	</ul>
	<br/>
		
';
$lang['utma'] = '156861353.2039886585.1231713618.1247618697.1247670804.57';
$lang['utmz'] = '156861353.1247618697.56.10.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
